/* GCodeMapper - maps movements of a g-code program from one surface to another, eg. plane to cylinder.
   Copyright (C) 2013 Martin Lederhilger <martin.lederhilger@gmx.at>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef GCODEREADER_H
#define GCODEREADER_H

#include <string>

namespace GCodeReader
{
  /// \brief  Indicates if the line contains a word.
  /// \param  letter This is the letter of the word to be searched for.
  /// \param  line The word is search in this line.
  /// \tparam ParamT Type of parameter of the word.
  ///                Eg. G01  -> void
  ///                    G..  -> int
  ///                    X..  -> double
  template<class ParamT>
  bool hasWord(const std::string& letter, const std::string& line);
  
  /// \brief  Extracts the parameter of a word from the line.
  /// \param  letter This is the letter of the word to be searched for.
  /// \param  line The word is search in this line.
  /// \tparam ParamT Type of parameter of the word.
  ///                Eg. G01  -> void
  ///                    G..  -> int
  ///                    X..  -> double
  /// \return \copybrief extractWordParameter
  template<class ParamT>
  ParamT extractWordParameter(const std::string& letter, const std::string& line);
  
  /// \brief Extracts the parameter of a word and removes the word from the line.
  /// \details \sa extractWordParameter
  /// \copybrief extractWordParameterAndRemove
  template<class ParamT>
  ParamT extractWordParameterAndRemove(const std::string& letter, std::string& line);
}

#endif